@@ -120,15 +120,15 @@ class SQuAREModelClient:
             response = requests.get(
                 url=f"{self.square_api_url}/main/task_result/{task_id}",
                 headers={"Authorization": f"Bearer {client_credentials()}"},
-                verify_ssl=self.verify_ssl,
+                verify=self.verify_ssl,
             )
-            resp = response.text()
+            resp = response.json()
 
             if response.status == 200:
-                result = ast.literal_eval(json.dumps(resp))
+                result = resp
                 break
             time.sleep(poll_interval)
-        return json.loads(result)["result"]
+        return result["result"]
 
     def __call__(self, model_name: str, pipeline: str, model_request: Dict) -> Dict:
         prediction = self.predict(
@@ -175,12 +175,12 @@ class SQuAREModelClient:
                 "Authorization": f"Bearer {client_credentials()}",
                 "Content-Type": "application/json",
             },
-            verify_ssl=self.verify_ssl,
+            verify=self.verify_ssl,
         )
-        result = response.text()
+        result = response.json()
 
         if response.status == 200:
-            self._wait_for_task(ast.literal_eval(result)["task_id"])
+            self._wait_for_task(result["task_id"])
         else:
             return response
 
@@ -244,14 +244,12 @@ class SQuAREModelClient:
             url=f"{self.square_api_url}/models/deploy",
             json=model_attributes,
             headers={"Authorization": f"Bearer {client_credentials()}"},
-            verify_ssl=self.verify_ssl,
+            verify=self.verify_ssl,
         )
-        result = response.text()
+        result = response.json()
         # print(response.status)
         if response.status == 200:
-            return self._wait_for_task(
-                ast.literal_eval(result)["task_id"], poll_interval=20
-            )
+            return self._wait_for_task(result["task_id"], poll_interval=20)
         else:
             return response
 
@@ -266,12 +264,12 @@ class SQuAREModelClient:
             url=f"{self.square_api_url}/models/remove/{model_identifier}",
             json=model_identifier,
             headers={"Authorization": f"Bearer {client_credentials()}"},
-            verify_ssl=self.verify_ssl,
+            verify=self.verify_ssl,
         )
-        result = response.text()
+        result = response.json()
         # print(response.status)
         if response.status == 200:
-            return self._wait_for_task(ast.literal_eval(result)["task_id"])
+            return self._wait_for_task(result["task_id"])
         else:
             return response
 
@@ -317,11 +315,11 @@ class SQuAREModelClient:
             url=f"{self.square_api_url}/models/{model_identifier}/add_worker/{number}",
             json=model_identifier,
             headers={"Authorization": f"Bearer {client_credentials()}"},
-            verify_ssl=self.verify_ssl,
+            verify=self.verify_ssl,
         )
-        result = response.text()
+        result = response.json()
         if response.status == 200:
-            return self._wait_for_task(ast.literal_eval(result)["task_id"])
+            return self._wait_for_task(result["task_id"])
         else:
             return response
 
@@ -334,10 +332,10 @@ class SQuAREModelClient:
             url=f"{self.square_api_url}/models/{model_identifier}/remove_worker/{number}",
             json=model_identifier,
             headers={"Authorization": f"Bearer {client_credentials()}"},
-            verify_ssl=self.verify_ssl,
+            verify=self.verify_ssl,
         )
-        result = response.text()
+        result = response.json()
         if response.status == 200:
-            return self._wait_for_task(ast.literal_eval(result)["task_id"])
+            return self._wait_for_task(result["task_id"])
         else:
             return response
